==> zio-aws-appsync_3-5.17.280.1-sources.jar: zio/aws/appsync/model/FunctionConfiguration.scala <==
package zio.aws.appsync.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.appsync.model.primitives.{
  MaxBatchSize,
  MappingTemplate,
  ResourceName
}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class FunctionConfiguration(
    functionId: Optional[String] = Optional.Absent,
    functionArn: Optional[String] = Optional.Absent,
    name: Optional[ResourceName] = Optional.Absent,
    description: Optional[String] = Optional.Absent,
    dataSourceName: Optional[ResourceName] = Optional.Absent,
    requestMappingTemplate: Optional[MappingTemplate] = Optional.Absent,
    responseMappingTemplate: Optional[MappingTemplate] = Optional.Absent,
    functionVersion: Optional[String] = Optional.Absent,
    syncConfig: Optional[zio.aws.appsync.model.SyncConfig] = Optional.Absent,
    maxBatchSize: Optional[MaxBatchSize] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.FunctionConfiguration = {
    import FunctionConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.FunctionConfiguration
      .builder()
      .optionallyWith(functionId.map(value => value: java.lang.String))(
        _.functionId
      )
      .optionallyWith(functionArn.map(value => value: java.lang.String))(
        _.functionArn
      )
      .optionallyWith(
        name.map(value => ResourceName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(
        dataSourceName.map(value =>
          ResourceName.unwrap(value): java.lang.String
        )
      )(_.dataSourceName)
      .optionallyWith(
        requestMappingTemplate.map(value =>
          MappingTemplate.unwrap(value): java.lang.String
        )
      )(_.requestMappingTemplate)
      .optionallyWith(
        responseMappingTemplate.map(value =>
          MappingTemplate.unwrap(value): java.lang.String
        )
      )(_.responseMappingTemplate)
      .optionallyWith(functionVersion.map(value => value: java.lang.String))(
        _.functionVersion
      )
      .optionallyWith(syncConfig.map(value => value.buildAwsValue()))(
        _.syncConfig
      )
      .optionallyWith(
        maxBatchSize.map(value => MaxBatchSize.unwrap(value): Integer)
      )(_.maxBatchSize)
      .build()
  }
  def asReadOnly: zio.aws.appsync.model.FunctionConfiguration.ReadOnly =
    zio.aws.appsync.model.FunctionConfiguration.wrap(buildAwsValue())
}
object FunctionConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.FunctionConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.FunctionConfiguration =
      zio.aws.appsync.model.FunctionConfiguration(
        functionId.map(value => value),
        functionArn.map(value => value),
        name.map(value => value),
        description.map(value => value),
        dataSourceName.map(value => value),
        requestMappingTemplate.map(value => value),
        responseMappingTemplate.map(value => value),
        functionVersion.map(value => value),
        syncConfig.map(value => value.asEditable),
        maxBatchSize.map(value => value)
      )
    def functionId: Optional[String]
    def functionArn: Optional[String]
    def name: Optional[ResourceName]
    def description: Optional[String]
    def dataSourceName: Optional[ResourceName]
    def requestMappingTemplate: Optional[MappingTemplate]
    def responseMappingTemplate: Optional[MappingTemplate]
    def functionVersion: Optional[String]
    def syncConfig: Optional[zio.aws.appsync.model.SyncConfig.ReadOnly]
    def maxBatchSize: Optional[MaxBatchSize]
    def getFunctionId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("functionId", functionId)
    def getFunctionArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("functionArn", functionArn)
    def getName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("name", name)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getDataSourceName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("dataSourceName", dataSourceName)
    def getRequestMappingTemplate: ZIO[Any, AwsError, MappingTemplate] =
      AwsError.unwrapOptionField(
        "requestMappingTemplate",
        requestMappingTemplate
      )
    def getResponseMappingTemplate: ZIO[Any, AwsError, MappingTemplate] =
      AwsError.unwrapOptionField(
        "responseMappingTemplate",
        responseMappingTemplate
      )
    def getFunctionVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("functionVersion", functionVersion)
    def getSyncConfig
        : ZIO[Any, AwsError, zio.aws.appsync.model.SyncConfig.ReadOnly] =
      AwsError.unwrapOptionField("syncConfig", syncConfig)
    def getMaxBatchSize: ZIO[Any, AwsError, MaxBatchSize] =
      AwsError.unwrapOptionField("maxBatchSize", maxBatchSize)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.FunctionConfiguration
  ) extends zio.aws.appsync.model.FunctionConfiguration.ReadOnly {
    override val functionId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.functionId())
      .map(value => value: String)
    override val functionArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.functionArn())
      .map(value => value: String)
    override val name: Optional[ResourceName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.appsync.model.primitives.ResourceName(value))
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val dataSourceName: Optional[ResourceName] = zio.aws.core.internal
      .optionalFromNullable(impl.dataSourceName())
      .map(value => zio.aws.appsync.model.primitives.ResourceName(value))
    override val requestMappingTemplate: Optional[MappingTemplate] =
      zio.aws.core.internal
        .optionalFromNullable(impl.requestMappingTemplate())
        .map(value => zio.aws.appsync.model.primitives.MappingTemplate(value))
    override val responseMappingTemplate: Optional[MappingTemplate] =
      zio.aws.core.internal
        .optionalFromNullable(impl.responseMappingTemplate())
        .map(value => zio.aws.appsync.model.primitives.MappingTemplate(value))
    override val functionVersion: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.functionVersion())
      .map(value => value: String)
    override val syncConfig
        : Optional[zio.aws.appsync.model.SyncConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.syncConfig())
        .map(value => zio.aws.appsync.model.SyncConfig.wrap(value))
    override val maxBatchSize: Optional[MaxBatchSize] = zio.aws.core.internal
      .optionalFromNullable(impl.maxBatchSize())
      .map(value => zio.aws.appsync.model.primitives.MaxBatchSize(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.FunctionConfiguration
  ): zio.aws.appsync.model.FunctionConfiguration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appsync_3-7.21.15.2-sources.jar: zio/aws/appsync/model/FunctionConfiguration.scala <==
package zio.aws.appsync.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.appsync.model.primitives.{
  Code,
  MaxBatchSize,
  MappingTemplate,
  ResourceName
}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class FunctionConfiguration(
    functionId: Optional[String] = Optional.Absent,
    functionArn: Optional[String] = Optional.Absent,
    name: Optional[ResourceName] = Optional.Absent,
    description: Optional[String] = Optional.Absent,
    dataSourceName: Optional[ResourceName] = Optional.Absent,
    requestMappingTemplate: Optional[MappingTemplate] = Optional.Absent,
    responseMappingTemplate: Optional[MappingTemplate] = Optional.Absent,
    functionVersion: Optional[String] = Optional.Absent,
    syncConfig: Optional[zio.aws.appsync.model.SyncConfig] = Optional.Absent,
    maxBatchSize: Optional[MaxBatchSize] = Optional.Absent,
    runtime: Optional[zio.aws.appsync.model.AppSyncRuntime] = Optional.Absent,
    code: Optional[Code] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appsync.model.FunctionConfiguration = {
    import FunctionConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appsync.model.FunctionConfiguration
      .builder()
      .optionallyWith(functionId.map(value => value: java.lang.String))(
        _.functionId
      )
      .optionallyWith(functionArn.map(value => value: java.lang.String))(
        _.functionArn
      )
      .optionallyWith(
        name.map(value => ResourceName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(
        dataSourceName.map(value =>
          ResourceName.unwrap(value): java.lang.String
        )
      )(_.dataSourceName)
      .optionallyWith(
        requestMappingTemplate.map(value =>
          MappingTemplate.unwrap(value): java.lang.String
        )
      )(_.requestMappingTemplate)
      .optionallyWith(
        responseMappingTemplate.map(value =>
          MappingTemplate.unwrap(value): java.lang.String
        )
      )(_.responseMappingTemplate)
      .optionallyWith(functionVersion.map(value => value: java.lang.String))(
        _.functionVersion
      )
      .optionallyWith(syncConfig.map(value => value.buildAwsValue()))(
        _.syncConfig
      )
      .optionallyWith(
        maxBatchSize.map(value => MaxBatchSize.unwrap(value): Integer)
      )(_.maxBatchSize)
      .optionallyWith(runtime.map(value => value.buildAwsValue()))(_.runtime)
      .optionallyWith(code.map(value => Code.unwrap(value): java.lang.String))(
        _.code
      )
      .build()
  }
  def asReadOnly: zio.aws.appsync.model.FunctionConfiguration.ReadOnly =
    zio.aws.appsync.model.FunctionConfiguration.wrap(buildAwsValue())
}
object FunctionConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appsync.model.FunctionConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appsync.model.FunctionConfiguration =
      zio.aws.appsync.model.FunctionConfiguration(
        functionId.map(value => value),
        functionArn.map(value => value),
        name.map(value => value),
        description.map(value => value),
        dataSourceName.map(value => value),
        requestMappingTemplate.map(value => value),
        responseMappingTemplate.map(value => value),
        functionVersion.map(value => value),
        syncConfig.map(value => value.asEditable),
        maxBatchSize.map(value => value),
        runtime.map(value => value.asEditable),
        code.map(value => value)
      )
    def functionId: Optional[String]
    def functionArn: Optional[String]
    def name: Optional[ResourceName]
    def description: Optional[String]
    def dataSourceName: Optional[ResourceName]
    def requestMappingTemplate: Optional[MappingTemplate]
    def responseMappingTemplate: Optional[MappingTemplate]
    def functionVersion: Optional[String]
    def syncConfig: Optional[zio.aws.appsync.model.SyncConfig.ReadOnly]
    def maxBatchSize: Optional[MaxBatchSize]
    def runtime: Optional[zio.aws.appsync.model.AppSyncRuntime.ReadOnly]
    def code: Optional[Code]
    def getFunctionId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("functionId", functionId)
    def getFunctionArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("functionArn", functionArn)
    def getName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("name", name)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getDataSourceName: ZIO[Any, AwsError, ResourceName] =
      AwsError.unwrapOptionField("dataSourceName", dataSourceName)
    def getRequestMappingTemplate: ZIO[Any, AwsError, MappingTemplate] =
      AwsError.unwrapOptionField(
        "requestMappingTemplate",
        requestMappingTemplate
      )
    def getResponseMappingTemplate: ZIO[Any, AwsError, MappingTemplate] =
      AwsError.unwrapOptionField(
        "responseMappingTemplate",
        responseMappingTemplate
      )
    def getFunctionVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("functionVersion", functionVersion)
    def getSyncConfig
        : ZIO[Any, AwsError, zio.aws.appsync.model.SyncConfig.ReadOnly] =
      AwsError.unwrapOptionField("syncConfig", syncConfig)
    def getMaxBatchSize: ZIO[Any, AwsError, MaxBatchSize] =
      AwsError.unwrapOptionField("maxBatchSize", maxBatchSize)
    def getRuntime
        : ZIO[Any, AwsError, zio.aws.appsync.model.AppSyncRuntime.ReadOnly] =
      AwsError.unwrapOptionField("runtime", runtime)
    def getCode: ZIO[Any, AwsError, Code] =
      AwsError.unwrapOptionField("code", code)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appsync.model.FunctionConfiguration
  ) extends zio.aws.appsync.model.FunctionConfiguration.ReadOnly {
    override val functionId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.functionId())
      .map(value => value: String)
    override val functionArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.functionArn())
      .map(value => value: String)
    override val name: Optional[ResourceName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.appsync.model.primitives.ResourceName(value))
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val dataSourceName: Optional[ResourceName] = zio.aws.core.internal
      .optionalFromNullable(impl.dataSourceName())
      .map(value => zio.aws.appsync.model.primitives.ResourceName(value))
    override val requestMappingTemplate: Optional[MappingTemplate] =
      zio.aws.core.internal
        .optionalFromNullable(impl.requestMappingTemplate())
        .map(value => zio.aws.appsync.model.primitives.MappingTemplate(value))
    override val responseMappingTemplate: Optional[MappingTemplate] =
      zio.aws.core.internal
        .optionalFromNullable(impl.responseMappingTemplate())
        .map(value => zio.aws.appsync.model.primitives.MappingTemplate(value))
    override val functionVersion: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.functionVersion())
      .map(value => value: String)
    override val syncConfig
        : Optional[zio.aws.appsync.model.SyncConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.syncConfig())
        .map(value => zio.aws.appsync.model.SyncConfig.wrap(value))
    override val maxBatchSize: Optional[MaxBatchSize] = zio.aws.core.internal
      .optionalFromNullable(impl.maxBatchSize())
      .map(value => zio.aws.appsync.model.primitives.MaxBatchSize(value))
    override val runtime
        : Optional[zio.aws.appsync.model.AppSyncRuntime.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.runtime())
        .map(value => zio.aws.appsync.model.AppSyncRuntime.wrap(value))
    override val code: Optional[Code] = zio.aws.core.internal
      .optionalFromNullable(impl.code())
      .map(value => zio.aws.appsync.model.primitives.Code(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appsync.model.FunctionConfiguration
  ): zio.aws.appsync.model.FunctionConfiguration.ReadOnly = new Wrapper(impl)
}
